CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
79 lines
2.0 KiB
C++
79 lines
2.0 KiB
C++
/* This testcase is part of GDB, the GNU debugger.
|
|
|
|
Copyright 2025 Free Software Foundation, Inc.
|
|
|
|
This program is free software; you can redistribute it and/or modify
|
|
it under the terms of the GNU General Public License as published by
|
|
the Free Software Foundation; either version 3 of the License, or
|
|
(at your option) any later version.
|
|
|
|
This program is distributed in the hope that it will be useful,
|
|
but WITHOUT ANY WARRANTY; without even the implied warranty of
|
|
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
|
|
GNU General Public License for more details.
|
|
|
|
You should have received a copy of the GNU General Public License
|
|
along with this program. If not, see <http://www.gnu.org/licenses/>. */
|
|
|
|
#ifdef DEVICE
|
|
|
|
#include <hip/hip_runtime.h>
|
|
#include <stdio.h>
|
|
#include <stdlib.h>
|
|
|
|
constexpr unsigned int NUM_BREAKPOINT_HITS = 5;
|
|
|
|
static __device__ void
|
|
break_here ()
|
|
{
|
|
}
|
|
|
|
extern "C" __global__ void
|
|
kernel ()
|
|
{
|
|
for (int n = 0; n < NUM_BREAKPOINT_HITS; ++n)
|
|
break_here ();
|
|
}
|
|
|
|
#else
|
|
|
|
#include <hip/hip_runtime.h>
|
|
|
|
#include "rocm-test-utils.h"
|
|
|
|
constexpr unsigned int NUM_ITEMS_PER_BLOCK = 256;
|
|
constexpr unsigned int NUM_BLOCKS = 128;
|
|
constexpr unsigned int NUM_ITEMS = NUM_ITEMS_PER_BLOCK * NUM_BLOCKS;
|
|
constexpr unsigned int NUM_LOAD_UNLOADS = 5;
|
|
|
|
int
|
|
main (int argc, const char **argv)
|
|
{
|
|
if (argc != 2)
|
|
{
|
|
fprintf (stderr, "Usage: %s <hip_module_path>\n", argv[0]);
|
|
return 1;
|
|
}
|
|
|
|
const auto module_path = argv[1];
|
|
hipModule_t module;
|
|
CHECK (hipModuleLoad (&module, module_path));
|
|
|
|
/* Launch the kernel. */
|
|
hipFunction_t function;
|
|
CHECK (hipModuleGetFunction (&function, module, "kernel"));
|
|
CHECK (hipModuleLaunchKernel (function, NUM_BLOCKS, 1, 1,
|
|
NUM_ITEMS_PER_BLOCK, 1, 1, 0, nullptr, nullptr,
|
|
nullptr));
|
|
|
|
/* Load and unload the module many times. */
|
|
for (int i = 0; i < NUM_LOAD_UNLOADS; ++i)
|
|
{
|
|
hipModule_t dummy_module;
|
|
CHECK (hipModuleLoad (&dummy_module, module_path));
|
|
CHECK (hipModuleUnload (dummy_module));
|
|
}
|
|
}
|
|
|
|
#endif
|